@@ -1,4 +1,4 @@
-# Copyright © 2012, 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -30,14 +30,14 @@ import subprocess as ipc
 import sys
 import tempfile
 
-from . import checker
-from . import ling
-from . import misc
-from . import paths
-from . import tags
-from . import terminal
+from lib import check
+from lib import ling
+from lib import misc
+from lib import paths
+from lib import tags
+from lib import terminal
 
-__version__ = '0.17'
+__version__ = '0.19'
 
 def initialize_terminal():
     if sys.stdout.isatty():
@@ -49,7 +49,7 @@ def initialize_terminal():
         errors='backslashreplace',
     )
 
-class Checker(checker.Checker):
+class Checker(check.Checker):
 
     def tag(self, tagname, *extra):
         if tagname in self.options.ignore_tags:
@@ -112,7 +112,7 @@ def check_deb(filename, *, options):
 
 def check_all(files, *, options):
     for filename in files:
-        if options.debian:
+        if options.unpack_deb:
             try:
                 check_deb(filename, options=options)
             except UnsupportedFileType:
@@ -123,12 +123,11 @@ def check_all(files, *, options):
 
 def main():
     initialize_terminal()
-    is_like_debian = misc.OSRelease().is_like('debian')
     ap = argparse.ArgumentParser(description=__doc__)
     ap.add_argument('--version', action='version', version='%(prog)s {}'.format(__version__))
     ap.add_argument('-l', '--language', metavar='<lang>', help='assume this langauge')
-    debian_help = 'allow checking Debian packages' + (' (enabled on this system)' if is_like_debian else '')
-    ap.add_argument('--debian', action='store_true', default=is_like_debian, help=debian_help)
+    ap.add_argument('--unpack-deb', action='store_true', help='allow unpacking Debian packages')
+    ap.add_argument('--file-type', metavar='<file-type>', help=argparse.SUPPRESS)
     ap.add_argument('--traceback', action='store_true', help=argparse.SUPPRESS)
     ap.add_argument('files', metavar='<file>', nargs='+')
     options = ap.parse_args()
@@ -153,4 +152,4 @@ def main():
 
 __all__ = ['main']
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
