@@ -1,4 +1,4 @@
-# Copyright © 2012, 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2014 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -24,11 +24,12 @@ squeeze Python abstract syntax trees into C integer expressions semantics
 
 import ast
 
+from lib import misc
+
 class BaseEvaluator(object):
 
     def __init__(self, node):
-        class context: pass
-        self._ctxt = context
+        self._ctxt = misc.Namespace()
         self._node = node
 
     def __call__(self):
@@ -203,7 +204,7 @@ class Evaluator(BaseEvaluator):
 class CodomainEvaluator(BaseEvaluator):
 
     def __init__(self, node, *, bits):
-        class context: pass
+        context = misc.Namespace()
         context.max = 1 << bits
         self._ctxt = context
         self._node = node
@@ -435,4 +436,4 @@ class Expression(object):
         e = CodomainEvaluator(self._node, bits=bits)
         return e()
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
