@@ -1,4 +1,4 @@
-# Copyright © 2012, 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -23,8 +23,6 @@ miscellanea
 '''
 
 import datetime
-import errno
-import shlex
 import sys
 import types
 
@@ -54,46 +52,6 @@ def sorted_vk(d):
     for k, v in sorted(d.items()):
         yield v
 
-class OSRelease(object):
-
-    '''
-    /etc/os-release parser
-
-    File format documentation:
-    http://www.freedesktop.org/software/systemd/man/os-release.html
-    '''
-
-    def __init__(self, path='/etc/os-release'):
-        self._id = None
-        self._id_like = ()
-        try:
-            file = open(path, 'rt', encoding='UTF-8')
-        except EnvironmentError as exc:
-            if exc.errno == errno.ENOENT:
-                return
-            raise
-        with file:
-            for line in file:
-                self._parse_line(line)
-
-    def _parse_line(self, line):
-        try:
-            name, value = line.split('=', 1)
-            [value] = shlex.split(value)
-        except ValueError:
-            return
-        if name == 'ID':
-            self._id = value
-        elif name == 'ID_LIKE':
-            self._id_like = frozenset(value.split())
-
-    def is_like(self, ident):
-        if ident is None:
-            raise TypeError('ident must not be None')
-        if self._id == ident:
-            return True
-        return ident in self._id_like
-
 def utc_now():
     '''
     timezone-aware variant of datetime.now()
@@ -128,4 +86,4 @@ Namespace()  # make pyflakes and coverage.py happy
 if sys.version_info >= (3, 3):
     Namespace = types.SimpleNamespace
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
