@@ -1,4 +1,4 @@
-# Copyright © 2012, 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -49,9 +49,9 @@ def this():
 
 # ----------------------------------------
 
-_parse_etag = re.compile('([A-Z]): (([\w-]+).*)').match
+_parse_etag = re.compile(r'([A-Z]): (([\w-]+).*)').match
 
-def parse_etag(contents, path, multi_line=False):
+def parse_etag(contents, path):
     match = _parse_etag(contents)
     if match is None:
         return
@@ -187,7 +187,7 @@ def queue_get(queue, process):
     while True:
         try:
             return queue.get(timeout=1)
-            # This semi-active waiting is ugly, but here doesn't seem be any
+            # This semi-active waiting is ugly, but there doesn't seem be any
             # obvious better way.
         except mp.queues.Empty:
             if process.exitcode is None:
@@ -253,15 +253,16 @@ def _mp_run_i18nspector(prog, options, path, queue):
     sys.argv = [prog] + list(options) + [path]
     orig_stdout = sys.stdout
     orig_stderr = sys.stderr
-    __file__ = prog
-    __file__  # make pyfakes happy
     code = compile(code, prog, 'exec')
     io_stdout = io.StringIO()
     io_stderr = io.StringIO()
+    gvars = dict(
+        __file__=prog,
+    )
     (sys.stdout, sys.stderr) = (io_stdout, io_stderr)
     try:
         try:
-            exec(code)
+            exec(code, gvars)
         finally:
             (sys.stdout, sys.stderr) = (orig_stdout, orig_stderr)
             stdout = io_stdout.getvalue()
@@ -411,4 +412,4 @@ def get_coverage():
             coverage.add(tag)
     return coverage
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
