@@ -1,4 +1,4 @@
-# Copyright © 2012, 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -227,6 +227,10 @@ class test_plural_exp:
     def test_nested_conditional(self):
         self.t('(2 ? 3 : 7) ? 23 : 37')
 
+    def test_badly_nested_conditional(self):
+        with assert_raises(self.error):
+            self.t('2 ? (3 : 7 ? ) : 23')
+
     def test_unary_plus(self):
         with assert_raises(self.error):
             self.t('-37')
@@ -239,11 +243,19 @@ class test_plural_exp:
         with assert_raises(self.error):
             self.t('23 + (+37)')
 
+    def test_func_call(self):
+        with assert_raises(self.error):
+            self.t('n(42)')
+        with assert_raises(self.error):
+            self.t('42(n)')
+
     def test_unbalanced_parentheses(self):
         with assert_raises(self.error):
             self.t('(6 * 7')
         with assert_raises(self.error):
             self.t('6 * 7)')
+        with assert_raises(self.error):
+            self.t('6) * (7')
 
     def test_dangling_binop(self):
         with assert_raises(self.error):
@@ -253,10 +265,36 @@ class test_plural_exp:
         with assert_raises(self.error):
             self.t('6 # 7')
 
+    def test_shift(self):
+        with assert_raises(self.error):
+            self.t('6 << 7')
+        with assert_raises(self.error):
+            self.t('6 >> 7')
+
+    def test_pow(self):
+        with assert_raises(self.error):
+            self.t('6 ** 7')
+
+    def test_floor_div(self):
+        with assert_raises(self.error):
+            self.t('6 // 7')
+
+    def test_tuple(self):
+        with assert_raises(self.error):
+            self.t('()')
+        with assert_raises(self.error):
+            self.t('(6, 7)')
+
     def test_exotic_whitespace(self):
         with assert_raises(self.error):
             self.t('6 *\xA07')
 
+    def test_empty(self):
+        with assert_raises(self.error):
+            self.t('')
+        with assert_raises(self.error):
+            self.t(' ')
+
 class test_codomain:
 
     def t(self, s, min_, max_=None):
@@ -598,7 +636,7 @@ class test_fix_date_format:
         # XXX In tzdata 2014f, EST stands only for (US) Eastern Time Zone, i.e.
         # -0500. But in the previous version of tzdata it could also stand for
         # (Australian) Eastern Standard/Summer Time.
-        # http://mm.icann.org/pipermail/tz/2014-June/021089.html
+        # https://mm.icann.org/pipermail/tz/2014-June/021089.html
 
     def test_abbrev_nonexistent(self):
         self.t('2005-12-20 10:33+JEST', None)
@@ -631,7 +669,7 @@ class test_string_formats:
 
     def test_nonempty(self):
         # XXX Update this number after editing data/string-formats:
-        expected = 27
+        expected = 28
         assert_equal(len(M.string_formats), expected)
 
     def test_lowercase(self):
@@ -640,4 +678,4 @@ class test_string_formats:
             assert_true(s)
             assert_equal(s, s.lower())
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
