@@ -1,4 +1,4 @@
-# Copyright © 2012, 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -18,6 +18,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+import nose
 from nose.tools import (
     assert_equal,
     assert_false,
@@ -33,8 +34,8 @@ from nose.tools import (
 
 from . import aux
 
-import lib.ling
 import lib.encodings
+import lib.ling
 
 L = lib.ling
 T = lib.ling.Language
@@ -75,6 +76,12 @@ class test_fix_codes:
         with assert_raises(L.FixingLanguageCodesFailed):
             self.t('el_RY', '')
 
+def test_language_repr():
+    # Language.__repr__() is never used by i18nspector itself,
+    # but it's useful for debugging test failures.
+    l = T('el')
+    assert_equal(repr(l), '<Language el>')
+
 class test_language_equality:
 
     # ==, !=, is_almost_equal()
@@ -186,6 +193,10 @@ class test_get_language_for_name:
     def test_found_comma_as_semicolon(self):
         self.t('Pashto, Pushto', 'ps')
 
+    def test_lone_comma(self):
+        with assert_raises(LookupError):
+            self.t(',', None)
+
     def test_not_found(self):
         with assert_raises(LookupError):
             self.t('Nadsat', None)
@@ -400,4 +411,185 @@ class test_unrepresentable_characters:
         result = lang.get_unrepresentable_characters(encoding)
         assert_not_equal(result, [])
 
-# vim:ts=4 sw=4 et
+def test_poedit():
+    # https://github.com/vslavik/poedit/blob/v1.8.1-oss/src/language_impl_legacy.h
+    # There won't be any new names in this table,
+    # so it's safe to harcode them all here.
+    def t(name, poedit_ll):
+        poedit_ll = L.parse_language(poedit_ll)
+        ll = L.get_language_for_name(name)
+        assert_equal(ll, poedit_ll)
+    def x(name, poedit_ll):
+        poedit_ll = L.parse_language(poedit_ll)
+        with assert_raises(LookupError):
+            L.get_language_for_name(name)
+        raise nose.SkipTest('expected failure')
+    yield t, 'Abkhazian', 'ab'
+    yield t, 'Afar', 'aa'
+    yield t, 'Afrikaans', 'af'
+    yield t, 'Albanian', 'sq'
+    yield t, 'Amharic', 'am'
+    yield t, 'Arabic', 'ar'
+    yield t, 'Armenian', 'hy'
+    yield t, 'Assamese', 'as'
+    yield t, 'Avestan', 'ae'
+    yield t, 'Aymara', 'ay'
+    yield t, 'Azerbaijani', 'az'
+    yield t, 'Bashkir', 'ba'
+    yield t, 'Basque', 'eu'
+    yield t, 'Belarusian', 'be'
+    yield t, 'Bengali', 'bn'
+    yield t, 'Bislama', 'bi'
+    yield t, 'Bosnian', 'bs'
+    yield t, 'Breton', 'br'
+    yield t, 'Bulgarian', 'bg'
+    yield t, 'Burmese', 'my'
+    yield t, 'Catalan', 'ca'
+    yield t, 'Chamorro', 'ch'
+    yield t, 'Chechen', 'ce'
+    yield t, 'Chichewa; Nyanja', 'ny'
+    yield t, 'Chinese', 'zh'
+    yield t, 'Church Slavic', 'cu'
+    yield t, 'Chuvash', 'cv'
+    yield t, 'Cornish', 'kw'
+    yield t, 'Corsican', 'co'
+    yield t, 'Croatian', 'hr'
+    yield t, 'Czech', 'cs'
+    yield t, 'Danish', 'da'
+    yield t, 'Dutch', 'nl'
+    yield t, 'Dzongkha', 'dz'
+    yield t, 'English', 'en'
+    yield t, 'Esperanto', 'eo'
+    yield t, 'Estonian', 'et'
+    yield t, 'Faroese', 'fo'
+    yield t, 'Fijian', 'fj'
+    yield t, 'Finnish', 'fi'
+    yield t, 'French', 'fr'
+    yield t, 'Frisian', 'fy'
+    yield t, 'Friulian', 'fur'
+    yield t, 'Gaelic', 'gd'
+    yield t, 'Galician', 'gl'
+    yield t, 'Georgian', 'ka'
+    yield t, 'German', 'de'
+    yield t, 'Greek', 'el'
+    yield t, 'Guarani', 'gn'
+    yield t, 'Gujarati', 'gu'
+    yield t, 'Hausa', 'ha'
+    yield t, 'Hebrew', 'he'
+    yield t, 'Herero', 'hz'
+    yield t, 'Hindi', 'hi'
+    yield t, 'Hiri Motu', 'ho'
+    yield t, 'Hungarian', 'hu'
+    yield t, 'Icelandic', 'is'
+    yield t, 'Indonesian', 'id'
+    yield t, 'Interlingua', 'ia'
+    yield t, 'Interlingue', 'ie'
+    yield t, 'Inuktitut', 'iu'
+    yield t, 'Inupiaq', 'ik'
+    yield t, 'Irish', 'ga'
+    yield t, 'Italian', 'it'
+    yield t, 'Japanese', 'ja'
+    yield t, 'Javanese', 'jv'  # https://github.com/vslavik/poedit/pull/193
+    yield t, 'Kalaallisut', 'kl'
+    yield t, 'Kannada', 'kn'
+    yield t, 'Kashmiri', 'ks'
+    yield t, 'Kazakh', 'kk'
+    yield t, 'Khmer', 'km'
+    yield t, 'Kikuyu', 'ki'
+    yield t, 'Kinyarwanda', 'rw'
+    yield t, 'Komi', 'kv'
+    yield t, 'Korean', 'ko'
+    yield t, 'Kuanyama', 'kj'
+    yield t, 'Kurdish', 'ku'
+    yield t, 'Kyrgyz', 'ky'
+    yield t, 'Lao', 'lo'
+    yield t, 'Latin', 'la'
+    yield t, 'Latvian', 'lv'
+    yield t, 'Letzeburgesch', 'lb'
+    yield t, 'Lingala', 'ln'
+    yield t, 'Lithuanian', 'lt'
+    yield t, 'Macedonian', 'mk'
+    yield t, 'Malagasy', 'mg'
+    yield t, 'Malay', 'ms'
+    yield t, 'Malayalam', 'ml'
+    yield t, 'Maltese', 'mt'
+    yield t, 'Maori', 'mi'
+    yield t, 'Marathi', 'mr'
+    yield t, 'Marshall', 'mh'
+    yield t, 'Moldavian', 'ro_MD'  # XXX poedit uses deprecated "mo"
+    yield t, 'Mongolian', 'mn'
+    yield t, 'Nauru', 'na'
+    yield t, 'Navajo', 'nv'
+    yield t, 'Ndebele, South', 'nr'
+    yield t, 'Ndonga', 'ng'
+    yield t, 'Nepali', 'ne'
+    yield t, 'Northern Sami', 'se'
+    yield t, 'Norwegian Bokmal', 'nb'
+    yield t, 'Norwegian Nynorsk', 'nn'
+    yield t, 'Occitan', 'oc'
+    yield t, 'Oriya', 'or'
+    yield t, 'Ossetian; Ossetic', 'os'
+    yield t, 'Pali', 'pi'
+    yield t, 'Panjabi', 'pa'
+    yield t, 'Pashto, Pushto', 'ps'
+    yield t, 'Persian', 'fa'
+    yield t, 'Polish', 'pl'
+    yield t, 'Portuguese', 'pt'
+    yield t, 'Quechua', 'qu'
+    yield t, 'Rhaeto-Romance', 'rm'
+    yield t, 'Romanian', 'ro'
+    yield t, 'Rundi', 'rn'
+    yield t, 'Russian', 'ru'
+    yield t, 'Samoan', 'sm'
+    yield t, 'Sangro', 'sg'
+    yield t, 'Sanskrit', 'sa'
+    yield t, 'Sardinian', 'sc'
+    yield t, 'Serbian', 'sr'
+    yield t, 'Sesotho', 'st'
+    yield t, 'Setswana', 'tn'
+    yield t, 'Shona', 'sn'
+    yield t, 'Sindhi', 'sd'
+    yield t, 'Sinhalese', 'si'
+    yield t, 'Siswati', 'ss'
+    yield t, 'Slovak', 'sk'
+    yield t, 'Slovenian', 'sl'
+    yield t, 'Somali', 'so'
+    yield t, 'Spanish', 'es'
+    yield t, 'Sundanese', 'su'
+    yield t, 'Swahili', 'sw'
+    yield t, 'Swedish', 'sv'
+    yield t, 'Tagalog', 'tl'
+    yield t, 'Tahitian', 'ty'
+    yield t, 'Tajik', 'tg'
+    yield t, 'Tamil', 'ta'
+    yield t, 'Tatar', 'tt'
+    yield t, 'Telugu', 'te'
+    yield t, 'Thai', 'th'
+    yield t, 'Tibetan', 'bo'
+    yield t, 'Tigrinya', 'ti'
+    yield t, 'Tonga', 'to'
+    yield t, 'Tsonga', 'ts'
+    yield t, 'Turkish', 'tr'
+    yield t, 'Turkmen', 'tk'
+    yield t, 'Twi', 'tw'
+    yield t, 'Ukrainian', 'uk'
+    yield t, 'Urdu', 'ur'
+    yield t, 'Uyghur', 'ug'
+    yield t, 'Uzbek', 'uz'
+    yield t, 'Vietnamese', 'vi'
+    yield t, 'Volapuk', 'vo'
+    yield t, 'Walloon', 'wa'
+    yield t, 'Welsh', 'cy'
+    yield t, 'Wolof', 'wo'
+    yield t, 'Xhosa', 'xh'
+    yield t, 'Yiddish', 'yi'
+    yield t, 'Yoruba', 'yo'
+    yield t, 'Zhuang', 'za'
+    yield t, 'Zulu', 'zu'
+    # TODO:
+    yield x, '(Afan) Oromo', 'om'
+    yield x, 'Bihari', 'bh'  # "bh" is marked as collective in ISO-639-2
+    yield x, 'Serbian (Latin)', 'sr_RS@latin'
+    yield x, 'Serbo-Croatian', 'sh'  # "sh" is deprecated in favor of "sr", "hr", "bs"
+
+# vim:ts=4 sts=4 sw=4 et
